<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>World News — IOSMail.net</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link href="/assets/bootstrap.min.css" rel="stylesheet">
    <link href="/assets/futuremail.css" rel="stylesheet">
    <style>
        /* (Same styles as previous solution for columns, articles, etc.) */
        .news-header {
            background: linear-gradient(90deg, #069296 70%, #48c6ef 100%);
            color: #fff;
            padding: 2rem 0 1.5rem 0;
            text-align: center;
            font-size: 2.3rem;
            font-weight: 700;
            letter-spacing: 0.03em;
            margin-bottom: 2.2rem;
            box-shadow: 0 2px 10px 0 rgba(6,146,150,0.07);
        }
        .news-columns {
            max-width: 1320px;
            margin: auto;
            gap: 2.5rem;
        }
        .news-column { padding: 0; }
        .news-agency-header {
            color: #fff;
            border-radius: 1.1rem 1.1rem 0 0;
            text-align: center;
            font-size: 1.1rem;
            font-weight: 700;
            letter-spacing: 0.03em;
            padding: 1.1rem 0 0.8rem 0;
            margin-bottom: 0.7rem;
            box-shadow: 0 2px 8px 0 rgba(33,203,243,0.06);
        }
        .news-article {
            background: #fff;
            border-radius: 1.1rem;
            box-shadow: 0 1.5px 8px 0 rgba(6,146,150,0.07);
            margin-bottom: 1.7rem;
            padding: 1.2rem 1.1rem 1rem 1.1rem;
            display: flex;
            flex-direction: column;
        }
        .news-img-wrap {
            height: 145px;
            background: #f0f5fa;
            border-radius: 0.8rem;
            margin-bottom: 0.8rem;
            overflow: hidden;
            display: flex;
            align-items: center;
            justify-content: center;
        }
        .news-img {
            width: 100%;
            height: 100%;
            object-fit: cover;
            border-radius: 0.8rem;
            min-height: 90px;
        }
        .news-title {
            font-size: 1.07rem;
            font-weight: 700;
            margin-bottom: 0.3rem;
            color: #0093e9;
            line-height: 1.22;
        }
        .news-date {
            color: #7a8a9a;
            font-size: 0.97rem;
            margin-bottom: 0.3rem;
        }
        .news-desc {
            color: #35434e;
            font-size: 0.98rem;
            margin-bottom: 0.7rem;
        }
        .news-link {
            color: #069296;
            text-decoration: underline;
            font-weight: 600;
            font-size: 0.99rem;
        }
        .news-link:hover {
            color: #21cbf3;
        }
        .news-pick-btn {
            position: absolute; top: 10px; right: 10px;
            z-index: 11;
        }
        .modal-backdrop {
            z-index: 9998 !important;
        }
        .modal {
            z-index: 9999 !important;
        }
        @media (max-width: 991px) {
            .news-columns { flex-direction: column; gap: 1.3rem; }
            .news-header { font-size: 1.5rem; }
            .news-column { margin-bottom: 2.2rem; }
        }
        @media (max-width: 700px) {
            .news-header { font-size: 1.2rem; padding: 1.2rem 0 1rem 0; }
            .news-columns { gap: 0.8rem; }
            .news-article { padding: 0.75rem 0.5rem 0.6rem 0.5rem; }
        }
    </style>
</head>
<body>
    <?php include('header.php'); ?>

    <div class="news-header position-relative">
        Global News — Top Stories From Trusted Sources
        <button type="button" class="btn btn-outline-light news-pick-btn" onclick="showNewsPicker()" title="Customize News">Change News Sources</button>
    </div>

    <div class="d-flex flex-lg-row flex-column news-columns" id="newsColumns"></div>

    <!-- News Picker Modal -->
    <div class="modal fade" id="newsPickerModal" tabindex="-1" aria-labelledby="newsPickerLabel" aria-hidden="true">
      <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content" style="border-radius:1.2rem;">
          <div class="modal-header" style="border:none;">
            <h5 class="modal-title" id="newsPickerLabel">Choose Your News Agencies (Pick 3)</h5>
            <button type="button" class="btn-close" onclick="hideNewsPicker()"></button>
          </div>
          <div class="modal-body">
            <form id="newsPickerForm">
                <div class="row" id="agencyChoices"></div>
                <div class="mt-3">
                    <button type="submit" class="btn btn-success w-100">Save Preferences</button>
                </div>
            </form>
          </div>
        </div>
      </div>
    </div>

    <?php include('footer.php'); ?>

    <script src="/assets/bootstrap.bundle.min.js"></script>
    <script>
    // Define ALL possible agencies (label, url, color, backup-url)
    const AGENCIES = [
        {name: "Yahoo News", url: "https://news.yahoo.com/rss/", color: "#6f42c1", backup: "https://feeds.npr.org/1001/rss.xml"},
        {name: "BBC News", url: "https://feeds.bbci.co.uk/news/rss.xml", color: "#1976d2", backup: "https://www.theguardian.com/world/rss"},
        {name: "CNN News", url: "https://rss.cnn.com/rss/edition.rss", color: "#e53935", backup: "https://feeds.foxnews.com/foxnews/latest"},
        {name: "Fox News", url: "https://feeds.foxnews.com/foxnews/latest", color: "#0058a3", backup: "https://www.reutersagency.com/feed/?best-topics=world&post_type=best"},
        {name: "NPR News", url: "https://feeds.npr.org/1001/rss.xml", color: "#3a6ea5", backup: "https://news.yahoo.com/rss/"},
        {name: "The Guardian", url: "https://www.theguardian.com/world/rss", color: "#ff9800", backup: "https://feeds.bbci.co.uk/news/rss.xml"},
    ];
    const DEFAULT = ["Yahoo News", "BBC News", "CNN News"];

    // Save/Load prefs in localStorage
    function savePrefs(prefs) {
        localStorage.setItem('userNewsPrefs', JSON.stringify(prefs));
    }
    function loadPrefs() {
        let prefs = localStorage.getItem('userNewsPrefs');
        if (prefs) {
            try {
                prefs = JSON.parse(prefs);
                if (Array.isArray(prefs) && prefs.length === 3) return prefs;
            } catch {}
        }
        return DEFAULT;
    }

    // UI for news agency picker
    function showNewsPicker() {
        const modal = new bootstrap.Modal(document.getElementById('newsPickerModal'));
        let prefs = loadPrefs();
        const $choices = document.getElementById('agencyChoices');
        $choices.innerHTML = '';
        AGENCIES.forEach((agency, i) => {
            let checked = prefs.includes(agency.name) ? "checked" : "";
            $choices.innerHTML += `<div class="col-12 mb-2"><label class="form-check-label">
                <input class="form-check-input me-2" type="checkbox" name="agency" value="${agency.name}" ${checked}>
                ${agency.name}
            </label></div>`;
        });
        document.getElementById('newsPickerForm').onsubmit = function(e){
            e.preventDefault();
            let boxes = Array.from(document.querySelectorAll("input[name='agency']:checked"));
            if (boxes.length !== 3) {
                alert("Please pick exactly 3 news sources.");
                return false;
            }
            let selected = boxes.map(b=>b.value);
            savePrefs(selected);
            modal.hide();
            window.location.reload();
        }
        modal.show();
    }
    function hideNewsPicker() {
        const modal = bootstrap.Modal.getInstance(document.getElementById('newsPickerModal'));
        modal.hide();
    }

    // Fetch RSS and render columns
    async function fetchRSS(url, backupUrl) {
        // Use PHP endpoint as a proxy (to bypass CORS); you will need to create 'rss-proxy.php'
        const endpoint = '/rss-proxy.php?url=' + encodeURIComponent(url);
        try {
            let resp = await fetch(endpoint);
            if (!resp.ok) throw "main failed";
            let text = await resp.text();
            if (!text.trim().length) throw "empty";
            return (new window.DOMParser()).parseFromString(text, "text/xml");
        } catch {
            // Try backup
            if (backupUrl) {
                let resp2 = await fetch('/rss-proxy.php?url=' + encodeURIComponent(backupUrl));
                if (!resp2.ok) return null;
                let text2 = await resp2.text();
                if (!text2.trim().length) return null;
                return (new window.DOMParser()).parseFromString(text2, "text/xml");
            }
            return null;
        }
    }

    function getImage(item) {
        // media:content, media:thumbnail, enclosure, or first image in desc
        let img = "/assets/news-placeholder.png";
        let media = item.getElementsByTagName("media:content");
        if (media.length && media[0].getAttribute("url")) img = media[0].getAttribute("url");
        else {
            let thumb = item.getElementsByTagName("media:thumbnail");
            if (thumb.length && thumb[0].getAttribute("url")) img = thumb[0].getAttribute("url");
            else {
                let enclosure = item.getElementsByTagName("enclosure");
                if (enclosure.length && enclosure[0].getAttribute("url")) img = enclosure[0].getAttribute("url");
                else {
                    let desc = item.getElementsByTagName("description");
                    if (desc.length) {
                        let m = desc[0].textContent.match(/<img.*?src=["']([^"']+)["']/);
                        if (m) img = m[1];
                    }
                }
            }
        }
        return img || "/assets/news-placeholder.png";
    }

    async function renderNewsColumns() {
        const prefs = loadPrefs();
        // Rotate columns daily
        const rot = (new Date()).getDay();
        const choices = [
            prefs[(0+rot)%3],
            prefs[(1+rot)%3],
            prefs[(2+rot)%3]
        ];
        const $cols = document.getElementById('newsColumns');
        $cols.innerHTML = "";
        for (let i=0; i<3; i++) {
            let agency = AGENCIES.find(a=>a.name===choices[i]);
            if (!agency) agency = AGENCIES[i];
            let color = agency.color;
            let feed = agency.url;
            let backup = agency.backup;
            let xml = await fetchRSS(feed, backup);
            let items = [];
            if (xml && xml.getElementsByTagName("item").length) {
                items = Array.from(xml.getElementsByTagName("item")).slice(0,5);
            }
            // If both main and backup fail, show a message
            $cols.innerHTML += `
            <div class="col-lg-4 news-column">
                <div class="news-agency-header" style="background: linear-gradient(90deg, ${color} 70%, #b2fefa 100%);">${agency.name}</div>
                ${(items.length?items.map(item=>{
                    let title = item.getElementsByTagName("title")[0]?.textContent || "";
                    let pubDate = item.getElementsByTagName("pubDate")[0]?.textContent || "";
                    let desc = item.getElementsByTagName("description")[0]?.textContent || "";
                    desc = desc.replace(/<[^>]+>/g, '').slice(0,240) + "...";
                    let link = item.getElementsByTagName("link")[0]?.textContent || "#";
                    let img = getImage(item);
                    return `
                        <div class="news-article">
                            <div class="news-img-wrap"><img class="news-img" src="${img}" loading="lazy" alt="news image"></div>
                            <div class="news-title">${title}</div>
                            <div class="news-date">${(new Date(pubDate)).toLocaleString()}</div>
                            <div class="news-desc">${desc}</div>
                            <a href="${link}" class="news-link" target="_blank" rel="noopener">Read more</a>
                        </div>`;
                }).join(""):`<div class="news-article"><div class="news-desc">Unable to load feed.</div></div>`)}
            </div>
            `;
        }
    }

    // Show news on page load
    document.addEventListener("DOMContentLoaded", renderNewsColumns);
    </script>
</body>
</html>
